@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: cinthash.c,v 1.8 2005/06/01 12:21:57 smarinier Exp $
+ * $Id: cinthash.c,v 1.9 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #ifndef LIBETPAN_CONFIG_H
 #	include "libetpan-config.h"
 #endif
