@@ -30,18 +30,14 @@
  */
 
 /*
- * $Id: connect.h,v 1.14 2005/06/01 13:38:34 smarinier Exp $
+ * $Id: connect.h,v 1.15 2006/05/22 13:39:40 hoa Exp $
  */
 
 #ifndef CONNECT_H
 
 #define CONNECT_H
 
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
-#endif
-#if HAVE_INTTYPES_H
+#ifdef HAVE_INTTYPES_H
 #	include <inttypes.h>
 #endif
 
