@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream_types.h,v 1.11 2005/06/01 12:21:57 smarinier Exp $
+ * $Id: mailstream_types.h,v 1.13 2006/03/22 08:10:47 hoa Exp $
  */
 
 #ifndef MAILSTREAM_TYPES_H
@@ -43,7 +43,7 @@ extern "C" {
 
 #define LIBETPAN_MAILSTREAM_DEBUG
 #ifndef LIBETPAN_CONFIG_H
-#	include "libetpan-config.h"
+#	include <libetpan/libetpan-config.h>
 #endif
 
 struct _mailstream;
