@@ -30,18 +30,17 @@
  */
 
 /*
- * $Id: mmapstring.c,v 1.20 2005/06/01 12:21:57 smarinier Exp $
+ * $Id: mmapstring.c,v 1.22 2006/06/26 11:50:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mmapstring.h"
 
 #include "chash.h"
 
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
-#endif
-
 #include <stdlib.h>
 #ifdef _MSC_VER
 #	include "win_etpan.h"
@@ -103,7 +102,7 @@ static size_t mmap_string_ceil = MMAP_STRING_DEFAULT_CEIL;
 #endif
 static chash * mmapstring_hashtable = NULL;
 
-static void mmapstring_hashtable_init()
+static void mmapstring_hashtable_init(void)
 {
   mmapstring_hashtable = chash_new(CHASH_DEFAULTSIZE, CHASH_COPYKEY);
 }
@@ -256,7 +255,7 @@ static MMAPString * mmap_string_realloc_file(MMAPString * string)
     data = mmap(NULL, string->allocated_len, PROT_WRITE | PROT_READ,
 		MAP_SHARED, fd, 0);
 
-    if (data == MAP_FAILED) {
+    if (data == (char *)MAP_FAILED) {
       close(fd);
       return NULL;
     }
@@ -279,7 +278,7 @@ static MMAPString * mmap_string_realloc_file(MMAPString * string)
     data = mmap(NULL, string->allocated_len, PROT_WRITE | PROT_READ,
 		MAP_SHARED, string->fd, 0);
 
-    if (data == MAP_FAILED)
+    if (data == (char *)MAP_FAILED)
       return NULL;
 
     string->mmapped_size = string->allocated_len;
