@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: dbdriver.c,v 1.10 2006/06/26 11:50:26 hoa Exp $
+ * $Id: dbdriver.c,v 1.11 2006/10/24 21:57:51 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -51,30 +51,30 @@ static int initialize(mailsession * session);
 
 static void uninitialize(mailsession * session);
 
-static int connect_path(mailsession * session, char * path);
+static int connect_path(mailsession * session, const char * path);
 
 static int logout(mailsession * session);
 
 static int expunge_folder(mailsession * session);
 
-static int status_folder(mailsession * session, char * mb,
+static int status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen);
 
-static int recent_number(mailsession * session, char * mb,
+static int recent_number(mailsession * session, const char * mb,
     uint32_t * result);
 
-static int unseen_number(mailsession * session, char * mb,
+static int unseen_number(mailsession * session, const char * mb,
     uint32_t * result);
 
-static int messages_number(mailsession * session, char * mb,
+static int messages_number(mailsession * session, const char * mb,
     uint32_t * result);
 
 static int append_message(mailsession * session,
-    char * message, size_t size);
+    const char * message, size_t size);
 
 static int append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags);
+    const char * message, size_t size, struct mail_flags * flags);
 
 static int get_messages_list(mailsession * session,
     struct mailmessage_list ** result);
@@ -256,7 +256,7 @@ static int db_get_next_validity(struct mail_cache_db * maildb,
   MMAPString * mmapstr;
   size_t cur_token;
   
-  mmapstr = mmap_string_new_len(serialized, serialized_len);
+  mmapstr = mmap_string_new("");
   if (mmapstr == NULL) {
     res = MAIL_ERROR_MEMORY;
     goto err;
@@ -270,6 +270,11 @@ static int db_get_next_validity(struct mail_cache_db * maildb,
   if (r >= 0) {
     size_t cur_token;
     
+    if (mmap_string_append_len(mmapstr, serialized, serialized_len) == NULL) {
+      res = MAIL_ERROR_MEMORY;
+      goto err;
+    }
+    
     cur_token = 0;
     r = mailimf_cache_int_read(mmapstr, &cur_token, &validity);
     if (r < 0)
@@ -535,7 +540,7 @@ static void uninitialize(mailsession * session)
   session->sess_data = NULL;
 }
 
-static int connect_path(mailsession * session, char * path)
+static int connect_path(mailsession * session, const char * path)
 {
   struct db_session_state_data * data;
   
@@ -673,7 +678,7 @@ static int expunge_folder(mailsession * session)
   return res;
 }
 
-static int status_folder(mailsession * session, char * mb,
+static int status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen)
 {
@@ -768,7 +773,7 @@ static int status_folder(mailsession * session, char * mb,
   return res;
 }
 
-static int recent_number(mailsession * session, char * mb,
+static int recent_number(mailsession * session, const char * mb,
     uint32_t * result)
 {
   uint32_t dummy_messages;
@@ -778,7 +783,7 @@ static int recent_number(mailsession * session, char * mb,
       &dummy_messages, result, &dummy_unseen);
 }
 
-static int unseen_number(mailsession * session, char * mb,
+static int unseen_number(mailsession * session, const char * mb,
     uint32_t * result)
 {
   uint32_t dummy_messages;
@@ -788,7 +793,7 @@ static int unseen_number(mailsession * session, char * mb,
       &dummy_messages, &dummy_recent, result);
 }
 
-static int messages_number(mailsession * session, char * mb,
+static int messages_number(mailsession * session, const char * mb,
     uint32_t * result)
 {
   uint32_t dummy_unseen;
@@ -799,13 +804,13 @@ static int messages_number(mailsession * session, char * mb,
 }
 
 static int append_message(mailsession * session,
-    char * message, size_t size)
+    const char * message, size_t size)
 {
   return append_message_flags(session, message, size, NULL);
 }
 
 static int append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags)
+    const char * message, size_t size, struct mail_flags * flags)
 {
   carray * msglist;
   unsigned int i;
