@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: imapdriver_cached_message.c,v 1.23 2005/08/13 14:59:42 hoa Exp $
+ * $Id: imapdriver_cached_message.c,v 1.25 2006/06/26 11:50:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "imapdriver_cached_message.h"
 
 #include "imapdriver_tools.h"
@@ -102,7 +106,7 @@ static int imap_get_flags(mailmessage * msg_info,
 			  struct mail_flags ** result);
 
 static mailmessage_driver local_imap_cached_message_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* msg_name */ "imap-cached",
 
   /* msg_initialize */ imap_initialize,
