@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: imapdriver_message.c,v 1.22 2005/08/13 14:59:42 hoa Exp $
+ * $Id: imapdriver_message.c,v 1.24 2006/06/26 11:50:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "imapdriver_message.h"
 
 #include "imapdriver_tools.h"
@@ -97,7 +101,7 @@ static void imap_flush(mailmessage * msg_info);
 static void imap_check(mailmessage * msg_info);
 
 static mailmessage_driver local_imap_message_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* msg_name */ "imap",
   
   /* msg_initialize */ imap_initialize,
