@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: imapdriver_tools.c,v 1.21 2005/06/01 16:04:41 hoa Exp $
+ * $Id: imapdriver_tools.c,v 1.22 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "imapdriver_tools.h"
 
 #include "maildriver.h"
