@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_types.h,v 1.23 2005/08/15 11:08:40 hoa Exp $
+ * $Id: imapdriver_types.h,v 1.25 2006/05/22 13:39:40 hoa Exp $
  */
 
 #ifndef IMAPDRIVER_TYPES_H
@@ -66,7 +66,7 @@ enum {
 /* cached IMAP driver for session */
 
 enum {
-  IMAPDRIVER_CACHED_SET_CACHE_DIRECTORY = 1,
+  IMAPDRIVER_CACHED_SET_CACHE_DIRECTORY = 1
 };
 
 struct imap_cached_session_state_data {
@@ -74,6 +74,7 @@ struct imap_cached_session_state_data {
   char * imap_quoted_mb;
   char imap_cache_directory[PATH_MAX];
   carray * imap_uid_list;
+  uint32_t imap_uidvalidity;
 };
 
 
@@ -145,7 +146,7 @@ enum {
   IMAP_AUTH_TYPE_SASL_PLAIN,       /* SASL plain */
   IMAP_AUTH_TYPE_SASL_SCRAM_MD5,   /* SASL SCRAM MD5 */
   IMAP_AUTH_TYPE_SASL_GSSAPI,      /* SASL GSSAPI */
-  IMAP_AUTH_TYPE_SASL_DIGEST_MD5,  /* SASL digest MD5 */
+  IMAP_AUTH_TYPE_SASL_DIGEST_MD5   /* SASL digest MD5 */
 };
 
 
