@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: maildirdriver_cached.c,v 1.14 2005/08/15 11:08:40 hoa Exp $
+ * $Id: maildirdriver_cached.c,v 1.17 2006/06/26 11:50:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "maildirdriver.h"
 
 #include <stdio.h>
@@ -66,30 +70,30 @@ static void uninitialize(mailsession * session);
 static int parameters(mailsession * session,
     int id, void * value);
 
-static int connect_path(mailsession * session, char * path);
+static int connect_path(mailsession * session, const char * path);
 
 static int logout(mailsession * session);
 
 static int expunge_folder(mailsession * session);
 
-static int status_folder(mailsession * session, char * mb,
+static int status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen);
 
-static int recent_number(mailsession * session, char * mb,
+static int recent_number(mailsession * session, const char * mb,
     uint32_t * result);
 
-static int unseen_number(mailsession * session, char * mb,
+static int unseen_number(mailsession * session, const char * mb,
     uint32_t * result);
 
-static int messages_number(mailsession * session, char * mb,
+static int messages_number(mailsession * session, const char * mb,
     uint32_t * result);
 
 static int append_message(mailsession * session,
-    char * message, size_t size);
+    const char * message, size_t size);
 
 static int append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags);
+    const char * message, size_t size, struct mail_flags * flags);
 
 static int get_messages_list(mailsession * session,
     struct mailmessage_list ** result);
@@ -106,7 +110,7 @@ static int get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
 static mailsession_driver local_maildir_cached_session_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
    /* sess_name */ "maildir-cached",
 
   /* sess_initialize */ initialize,
@@ -434,7 +438,7 @@ static int get_cache_folder(mailsession * session, char ** result)
 }
 
 
-static int connect_path(mailsession * session, char * path)
+static int connect_path(mailsession * session, const char * path)
 {
   int r;
   int res;
@@ -482,7 +486,7 @@ static int logout(mailsession * session)
   return MAIL_NO_ERROR;
 }
 
-static int status_folder(mailsession * session, char * mb,
+static int status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen)
 {
@@ -490,19 +494,19 @@ static int status_folder(mailsession * session, char * mb,
       result_messages, result_recent, result_unseen);
 }
 
-static int messages_number(mailsession * session, char * mb,
+static int messages_number(mailsession * session, const char * mb,
     uint32_t * result)
 {
   return mailsession_messages_number(get_ancestor(session), mb, result);
 }
 
-static int unseen_number(mailsession * session, char * mb,
+static int unseen_number(mailsession * session, const char * mb,
     uint32_t * result)
 {
   return mailsession_unseen_number(get_ancestor(session), mb, result);
 }
 
-static int recent_number(mailsession * session, char * mb,
+static int recent_number(mailsession * session, const char * mb,
     uint32_t * result)
 {
   return mailsession_recent_number(get_ancestor(session), mb, result);
@@ -510,7 +514,7 @@ static int recent_number(mailsession * session, char * mb,
 
 
 static int append_message(mailsession * session,
-    char * message, size_t size)
+    const char * message, size_t size)
 {
 #if 0
   return mailsession_append_message(get_ancestor(session), message, size);
@@ -519,7 +523,7 @@ static int append_message(mailsession * session,
 }
 
 static int append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags)
+    const char * message, size_t size, struct mail_flags * flags)
 {
   struct maildir * md;
   int r;
