@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mhdriver.c,v 1.31 2005/08/15 11:08:40 hoa Exp $
+ * $Id: mhdriver.c,v 1.34 2006/06/26 11:50:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mhdriver.h"
 
 #include <stdio.h>
@@ -58,48 +62,48 @@ static int mhdriver_initialize(mailsession * session);
 
 static void mhdriver_uninitialize(mailsession * session);
 
-static int mhdriver_connect_path(mailsession * session, char * path);
+static int mhdriver_connect_path(mailsession * session, const char * path);
 static int mhdriver_logout(mailsession * session);
 
-static int mhdriver_build_folder_name(mailsession * session, char * mb,
-				      char * name, char ** result);
-static int mhdriver_create_folder(mailsession * session, char * mb);
+static int mhdriver_build_folder_name(mailsession * session, const char * mb,
+				      const char * name, char ** result);
+static int mhdriver_create_folder(mailsession * session, const char * mb);
 
-static int mhdriver_delete_folder(mailsession * session, char * mb);
+static int mhdriver_delete_folder(mailsession * session, const char * mb);
 
-static int mhdriver_rename_folder(mailsession * session, char * mb,
-				  char * new_name);
+static int mhdriver_rename_folder(mailsession * session, const char * mb,
+				  const char * new_name);
 
-static int mhdriver_select_folder(mailsession * session, char * mb);
+static int mhdriver_select_folder(mailsession * session, const char * mb);
 
-static int mhdriver_status_folder(mailsession * session, char * mb,
+static int mhdriver_status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen);
 
-static int mhdriver_messages_number(mailsession * session, char * mb,
+static int mhdriver_messages_number(mailsession * session, const char * mb,
 				    uint32_t * result);
 
-static int mhdriver_list_folders(mailsession * session, char * mb,
+static int mhdriver_list_folders(mailsession * session, const char * mb,
 				 struct mail_list ** result);
 
-static int mhdriver_lsub_folders(mailsession * session, char * mb,
+static int mhdriver_lsub_folders(mailsession * session, const char * mb,
 				 struct mail_list ** result);
 
-static int mhdriver_subscribe_folder(mailsession * session, char * mb);
+static int mhdriver_subscribe_folder(mailsession * session, const char * mb);
 
-static int mhdriver_unsubscribe_folder(mailsession * session, char * mb);
+static int mhdriver_unsubscribe_folder(mailsession * session, const char * mb);
 
 static int mhdriver_append_message(mailsession * session,
-				   char * message, size_t size);
+				   const char * message, size_t size);
 static int mhdriver_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags);
+    const char * message, size_t size, struct mail_flags * flags);
 static int mhdriver_copy_message(mailsession * session,
-				 uint32_t num, char * mb);
+				 uint32_t num, const char * mb);
 
 static int mhdriver_remove_message(mailsession * session, uint32_t num);
 
 static int mhdriver_move_message(mailsession * session,
-				 uint32_t num, char * mb);
+				 uint32_t num, const char * mb);
 
 static int mhdriver_get_messages_list(mailsession * session,
 				      struct mailmessage_list ** result);
@@ -112,7 +116,7 @@ static int mhdriver_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mh_session_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "mh",
 
   /* sess_initialize */ mhdriver_initialize,
@@ -227,7 +231,7 @@ static inline struct mailmh_folder * get_mh_cur_folder(mailsession * session)
   return get_data(session)->mh_cur_folder;
 }
 
-static int add_to_list(mailsession * session, char * mb)
+static int add_to_list(mailsession * session, const char * mb)
 {
   char * new_mb;
   struct mh_session_state_data * data;
@@ -241,14 +245,14 @@ static int add_to_list(mailsession * session, char * mb)
 
   r = clist_append(data->mh_subscribed_list, new_mb);
   if (r < 0) {
-    free(mb);
+    free(new_mb);
     return -1;
   }
 
   return 0;
 }
 
-static int remove_from_list(mailsession * session, char * mb)
+static int remove_from_list(mailsession * session, const char * mb)
 {
   clistiter * cur;
   struct mh_session_state_data * data;
@@ -313,7 +317,7 @@ static void mhdriver_uninitialize(mailsession * session)
 }
 
 
-static int mhdriver_connect_path(mailsession * session, char * path)
+static int mhdriver_connect_path(mailsession * session, const char * path)
 {
   struct mailmh * mh;
 
@@ -346,8 +350,8 @@ static int mhdriver_logout(mailsession * session)
 
 /* folders operations */
 
-static int mhdriver_build_folder_name(mailsession * session, char * mb,
-				      char * name, char ** result)
+static int mhdriver_build_folder_name(mailsession * session, const char * mb,
+				      const char * name, char ** result)
 {
   char * folder_name;
 
@@ -364,13 +368,13 @@ static int mhdriver_build_folder_name(mailsession * session, char * mb,
   return MAIL_NO_ERROR;
 }
 
-static int get_parent(mailsession * session, char * mb,
+static int get_parent(mailsession * session, const char * mb,
 		      struct mailmh_folder ** result_folder,
-		      char ** result_name)
+		      const char ** result_name)
 {
-  char * name;
+  const char * name;
   size_t length;
-  int i;
+  size_t i;
   char * parent_name;
   struct mailmh_folder * parent;
   struct mailmh * mh;
@@ -404,7 +408,7 @@ static int get_parent(mailsession * session, char * mb,
   return MAIL_NO_ERROR;
 }
 
-static int mhdriver_create_folder(mailsession * session, char * mb)
+static int mhdriver_create_folder(mailsession * session, const char * mb)
 {
   int r;
   struct mailmh_folder * parent;
@@ -419,7 +423,7 @@ static int mhdriver_create_folder(mailsession * session, char * mb)
   return mhdriver_mh_error_to_mail_error(r);
 }
 
-static int mhdriver_delete_folder(mailsession * session, char * mb)
+static int mhdriver_delete_folder(mailsession * session, const char * mb)
 {
   int r;
   struct mailmh_folder * folder;
@@ -441,8 +445,8 @@ static int mhdriver_delete_folder(mailsession * session, char * mb)
   return mhdriver_mh_error_to_mail_error(r);
 }
 
-static int mhdriver_rename_folder(mailsession * session, char * mb,
-				  char * new_name)
+static int mhdriver_rename_folder(mailsession * session, const char * mb,
+				  const char * new_name)
 {
   struct mailmh_folder * src_folder;
   struct mailmh_folder * dst_folder;
@@ -470,7 +474,7 @@ static int mhdriver_rename_folder(mailsession * session, char * mb,
   return mhdriver_mh_error_to_mail_error(r);
 }
 
-static int mhdriver_select_folder(mailsession * session, char * mb)
+static int mhdriver_select_folder(mailsession * session, const char * mb)
 {
   struct mailmh_folder * folder;
   struct mailmh * mh;
@@ -492,7 +496,7 @@ static int mhdriver_select_folder(mailsession * session, char * mb)
   return mhdriver_mh_error_to_mail_error(r);
 }
 
-static int mhdriver_status_folder(mailsession * session, char * mb,
+static int mhdriver_status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen)
 {
@@ -510,7 +514,7 @@ static int mhdriver_status_folder(mailsession * session, char * mb,
   return MAIL_NO_ERROR;
 }
 
-static int mhdriver_messages_number(mailsession * session, char * mb,
+static int mhdriver_messages_number(mailsession * session, const char * mb,
 				    uint32_t * result)
 {
   struct mailmh_folder * folder;
@@ -608,7 +612,7 @@ static int get_list_folders(struct mailmh_folder * folder, clist ** result)
 }
 
 
-static int mhdriver_list_folders(mailsession * session, char * mb,
+static int mhdriver_list_folders(mailsession * session, const char * mb,
 				 struct mail_list ** result)
 {
   clist * list;
@@ -643,7 +647,7 @@ static int mhdriver_list_folders(mailsession * session, char * mb,
   return MAIL_ERROR_MEMORY;
 }
 
-static int mhdriver_lsub_folders(mailsession * session, char * mb,
+static int mhdriver_lsub_folders(mailsession * session, const char * mb,
 				 struct mail_list ** result)
 {
   clist * subscribed;
@@ -695,7 +699,7 @@ static int mhdriver_lsub_folders(mailsession * session, char * mb,
   return MAIL_ERROR_MEMORY;
 }
 
-static int mhdriver_subscribe_folder(mailsession * session, char * mb)
+static int mhdriver_subscribe_folder(mailsession * session, const char * mb)
 {
   int r;
 
@@ -706,7 +710,7 @@ static int mhdriver_subscribe_folder(mailsession * session, char * mb)
   return MAIL_NO_ERROR;
 }
 
-static int mhdriver_unsubscribe_folder(mailsession * session, char * mb)
+static int mhdriver_unsubscribe_folder(mailsession * session, const char * mb)
 {
   int r;
 
@@ -720,7 +724,7 @@ static int mhdriver_unsubscribe_folder(mailsession * session, char * mb)
 /* messages operations */
 
 static int mhdriver_append_message(mailsession * session,
-				   char * message, size_t size)
+				   const char * message, size_t size)
 {
   int r;
   struct mailmh_folder * folder;
@@ -741,13 +745,13 @@ static int mhdriver_append_message(mailsession * session,
 }
 
 static int mhdriver_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags)
+    const char * message, size_t size, struct mail_flags * flags)
 {
   return mhdriver_append_message(session, message, size);
 }
 
 static int mhdriver_copy_message(mailsession * session,
-				 uint32_t num, char * mb)
+				 uint32_t num, const char * mb)
 {
   int fd;
   int r;
@@ -810,7 +814,7 @@ static int mhdriver_remove_message(mailsession * session, uint32_t num)
 }
 
 static int mhdriver_move_message(mailsession * session,
-				 uint32_t num, char * mb)
+				 uint32_t num, const char * mb)
 {
   int r;
   struct mailmh_folder * src_folder;
