@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mhdriver_cached.c,v 1.43 2005/08/15 11:08:40 hoa Exp $
+ * $Id: mhdriver_cached.c,v 1.46 2006/06/26 11:50:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mhdriver_cached.h"
 
 #include <stdio.h>
@@ -70,58 +74,58 @@ static void mhdriver_cached_uninitialize(mailsession * session);
 static int mhdriver_cached_parameters(mailsession * session,
 				      int id, void * value);
 
-static int mhdriver_cached_connect_path(mailsession * session, char * path);
+static int mhdriver_cached_connect_path(mailsession * session, const char * path);
 static int mhdriver_cached_logout(mailsession * session);
 
-static int mhdriver_cached_build_folder_name(mailsession * session, char * mb,
-					     char * name, char ** result);
-static int mhdriver_cached_create_folder(mailsession * session, char * mb);
+static int mhdriver_cached_build_folder_name(mailsession * session, const char * mb,
+					     const char * name, char ** result);
+static int mhdriver_cached_create_folder(mailsession * session, const char * mb);
 
-static int mhdriver_cached_delete_folder(mailsession * session, char * mb);
+static int mhdriver_cached_delete_folder(mailsession * session, const char * mb);
 
-static int mhdriver_cached_rename_folder(mailsession * session, char * mb,
-					 char * new_name);
+static int mhdriver_cached_rename_folder(mailsession * session, const char * mb,
+					 const char * new_name);
 
 static int mhdriver_cached_check_folder(mailsession * session);
 
-static int mhdriver_cached_select_folder(mailsession * session, char * mb);
+static int mhdriver_cached_select_folder(mailsession * session, const char * mb);
 
 static int mhdriver_cached_expunge_folder(mailsession * session);
 
-static int mhdriver_cached_status_folder(mailsession * session, char * mb,
+static int mhdriver_cached_status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen);
 
-static int mhdriver_cached_messages_number(mailsession * session, char * mb,
+static int mhdriver_cached_messages_number(mailsession * session, const char * mb,
 					   uint32_t * result);
-static int mhdriver_cached_recent_number(mailsession * session, char * mb,
+static int mhdriver_cached_recent_number(mailsession * session, const char * mb,
 					   uint32_t * result);
-static int mhdriver_cached_unseen_number(mailsession * session, char * mb,
+static int mhdriver_cached_unseen_number(mailsession * session, const char * mb,
 					   uint32_t * result);
 
-static int mhdriver_cached_list_folders(mailsession * session, char * mb,
+static int mhdriver_cached_list_folders(mailsession * session, const char * mb,
 					struct mail_list ** result);
 
-static int mhdriver_cached_lsub_folders(mailsession * session, char * mb,
+static int mhdriver_cached_lsub_folders(mailsession * session, const char * mb,
 					struct mail_list ** result);
 
-static int mhdriver_cached_subscribe_folder(mailsession * session, char * mb);
+static int mhdriver_cached_subscribe_folder(mailsession * session, const char * mb);
 
 static int mhdriver_cached_unsubscribe_folder(mailsession * session,
-					      char * mb);
+					      const char * mb);
 
 static int mhdriver_cached_append_message(mailsession * session,
-					  char * message, size_t size);
+					  const char * message, size_t size);
 static int mhdriver_cached_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags);
+    const char * message, size_t size, struct mail_flags * flags);
 static int mhdriver_cached_copy_message(mailsession * session,
-					uint32_t num, char * mb);
+					uint32_t num, const char * mb);
 
 static int mhdriver_cached_remove_message(mailsession * session,
 					  uint32_t num);
 
 static int mhdriver_cached_move_message(mailsession * session,
-					uint32_t num, char * mb);
+					uint32_t num, const char * mb);
 
 static int
 mhdriver_cached_get_messages_list(mailsession * session,
@@ -139,7 +143,7 @@ static int mhdriver_cached_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mh_cached_session_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "mh-cached",
 
   /* sess_initialize */ mhdriver_cached_initialize,
@@ -552,7 +556,7 @@ static int mhdriver_cached_parameters(mailsession * session,
   return MAIL_ERROR_INVAL;
 }
 
-static int mhdriver_cached_connect_path(mailsession * session, char * path)
+static int mhdriver_cached_connect_path(mailsession * session, const char * path)
 {
   return mailsession_connect_path(get_ancestor(session), path);
 }
@@ -588,31 +592,31 @@ static int mhdriver_cached_check_folder(mailsession * session)
 
 /* folders operations */
 
-static int mhdriver_cached_build_folder_name(mailsession * session, char * mb,
-					     char * name, char ** result)
+static int mhdriver_cached_build_folder_name(mailsession * session, const char * mb,
+					     const char * name, char ** result)
 {
   return mailsession_build_folder_name(get_ancestor(session),
       mb, name, result);
 }
 
-static int mhdriver_cached_create_folder(mailsession * session, char * mb)
+static int mhdriver_cached_create_folder(mailsession * session, const char * mb)
 {
   return mailsession_create_folder(get_ancestor(session), mb);
 }
 
-static int mhdriver_cached_delete_folder(mailsession * session, char * mb)
+static int mhdriver_cached_delete_folder(mailsession * session, const char * mb)
 {
   return mailsession_delete_folder(get_ancestor(session), mb);
 }
 
-static int mhdriver_cached_rename_folder(mailsession * session, char * mb,
-					 char * new_name)
+static int mhdriver_cached_rename_folder(mailsession * session, const char * mb,
+					 const char * new_name)
 {
   return mailsession_rename_folder(get_ancestor(session), mb, new_name);
 }
 
 static int get_cache_directory(mailsession * session,
-			       char * path, char ** result)
+			       const char * path, char ** result)
 {
   char * quoted_mb;
   char dirname[PATH_MAX];
@@ -656,7 +660,7 @@ static int get_cache_directory(mailsession * session,
   return res;
 }
 
-static int mhdriver_cached_select_folder(mailsession * session, char * mb)
+static int mhdriver_cached_select_folder(mailsession * session, const char * mb)
 {
   int r;
   int res;
@@ -773,7 +777,7 @@ static int mhdriver_cached_expunge_folder(mailsession * session)
 }
 
 
-static int mhdriver_cached_status_folder(mailsession * session, char * mb,
+static int mhdriver_cached_status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages,
     uint32_t * result_recent,
     uint32_t * result_unseen)
@@ -872,13 +876,13 @@ static int mhdriver_cached_status_folder(mailsession * session, char * mb,
   return res;
 }
 
-static int mhdriver_cached_messages_number(mailsession * session, char * mb,
+static int mhdriver_cached_messages_number(mailsession * session, const char * mb,
 					   uint32_t * result)
 {
   return mailsession_messages_number(get_ancestor(session), mb, result);
 }
 
-static int mhdriver_cached_recent_number(mailsession * session, char * mb,
+static int mhdriver_cached_recent_number(mailsession * session, const char * mb,
     uint32_t * result)
 {
   uint32_t messages;
@@ -896,7 +900,7 @@ static int mhdriver_cached_recent_number(mailsession * session, char * mb,
 }
 
 
-static int mhdriver_cached_unseen_number(mailsession * session, char * mb,
+static int mhdriver_cached_unseen_number(mailsession * session, const char * mb,
     uint32_t * result)
 {
   uint32_t messages;
@@ -914,25 +918,25 @@ static int mhdriver_cached_unseen_number(mailsession * session, char * mb,
 }
 
   
-static int mhdriver_cached_list_folders(mailsession * session, char * mb,
+static int mhdriver_cached_list_folders(mailsession * session, const char * mb,
 					struct mail_list ** result)
 {
   return mailsession_list_folders(get_ancestor(session), mb, result);
 }
 
-static int mhdriver_cached_lsub_folders(mailsession * session, char * mb,
+static int mhdriver_cached_lsub_folders(mailsession * session, const char * mb,
 					struct mail_list ** result)
 {
   return mailsession_lsub_folders(get_ancestor(session), mb, result);
 }
 
-static int mhdriver_cached_subscribe_folder(mailsession * session, char * mb)
+static int mhdriver_cached_subscribe_folder(mailsession * session, const char * mb)
 {
   return mailsession_subscribe_folder(get_ancestor(session), mb);
 }
 
 static int mhdriver_cached_unsubscribe_folder(mailsession * session,
-					      char * mb)
+					      const char * mb)
 {
   return mailsession_unsubscribe_folder(get_ancestor(session), mb);
 }
@@ -940,14 +944,14 @@ static int mhdriver_cached_unsubscribe_folder(mailsession * session,
 /* messages operations */
 
 static int mhdriver_cached_append_message(mailsession * session,
-					  char * message, size_t size)
+					  const char * message, size_t size)
 {
   return mhdriver_cached_append_message_flags(session,
       message, size, NULL);
 }
 
 static int mhdriver_cached_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags)
+    const char * message, size_t size, struct mail_flags * flags)
 { 
   int r;
   struct mailmh_folder * folder;
@@ -1024,7 +1028,7 @@ static int mhdriver_cached_append_message_flags(mailsession * session,
 }
 
 static int mhdriver_cached_copy_message(mailsession * session,
-					uint32_t num, char * mb)
+					uint32_t num, const char * mb)
 {
   return mailsession_copy_message(get_ancestor(session), num, mb);
 }
@@ -1035,7 +1039,7 @@ static int mhdriver_cached_remove_message(mailsession * session, uint32_t num)
 }
 
 static int mhdriver_cached_move_message(mailsession * session,
-					uint32_t num, char * mb)
+					uint32_t num, const char * mb)
 {
   return mailsession_move_message(get_ancestor(session), num, mb);
 }
