@@ -30,16 +30,15 @@
  */
 
 /*
- * $Id: mhdriver_tools.c,v 1.22 2005/06/01 20:23:15 hoa Exp $
+ * $Id: mhdriver_tools.c,v 1.25 2006/06/26 11:50:26 hoa Exp $
  */
 
-#include "mhdriver_tools.h"
-
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
 #endif
 
+#include "mhdriver_tools.h"
+
 #include "mailmessage.h"
 #include "mhdriver.h"
 #include "mhdriver_cached.h"
@@ -49,10 +48,10 @@
 #include "imfcache.h"
 #include "mail_cache_db.h"
 
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
-#if HAVE_SYS_MMAN_H
+#ifdef HAVE_SYS_MMAN_H
 #	include <sys/mman.h>
 #endif
 #include <sys/types.h>
@@ -169,7 +168,7 @@ int mhdriver_fetch_message(mailsession * session, uint32_t index,
   }
 
   str = mmap(NULL, size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (str == MAP_FAILED) {
+  if (str == (char *)MAP_FAILED) {
     res = MAIL_ERROR_FETCH;
     goto close;
   }
@@ -177,20 +176,22 @@ int mhdriver_fetch_message(mailsession * session, uint32_t index,
   /* strip "From " header for broken implementations */
   /* XXX - called twice, make a function */
   cur_token = 0;
-  if (strncmp("From ", str, 5) == 0) {
-    cur_token += 5;
+  if (size > 5) {
+    if (strncmp("From ", str, 5) == 0) {
+      cur_token += 5;
     
-    while (1) {
-      if (str[cur_token] == '\n') {
+      while (1) {
+        if (str[cur_token] == '\n') {
+          cur_token ++;
+          break;
+        }
+        if (cur_token >= size)
+          break;
         cur_token ++;
-        break;
       }
-      if (cur_token >= size)
-	break;
-      cur_token ++;
     }
   }
-
+  
   mmapstr = mmap_string_new_len(str + cur_token, size - cur_token);
   if (mmapstr == NULL) {
     res = MAIL_ERROR_MEMORY;
@@ -263,7 +264,7 @@ int mhdriver_fetch_header(mailsession * session, uint32_t index,
   }
 
   str = mmap(NULL, size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (str == MAP_FAILED) {
+  if (str == (char *)MAP_FAILED) {
     res = MAIL_ERROR_FETCH;
     goto close;
   }
