@@ -30,19 +30,23 @@
  */
 
 /*
- * $Id: mime_message_driver.c,v 1.10 2005/08/13 14:59:42 hoa Exp $
+ * $Id: mime_message_driver.c,v 1.12 2006/06/26 11:50:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mime_message_driver.h"
 
 #include "libetpan-config.h"
 
 #include <sys/stat.h>
 #include <sys/types.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
-#if HAVE_SYS_MMAN_H
+#ifdef HAVE_SYS_MMAN_H
 #	include <sys/mman.h>
 #endif
 #include <stdlib.h>
@@ -199,7 +203,7 @@ static int file_to_mmapstr(FILE * f,
   }
   
   data = mmap(NULL, buf.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (data == MAP_FAILED) {
+  if (data == (char *)MAP_FAILED) {
     res = MAIL_ERROR_FILE;
     
     goto err;
@@ -261,7 +265,7 @@ static int file_body_to_mmapstr(FILE * f,
   }
   
   data = mmap(NULL, buf.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (data == MAP_FAILED) {
+  if (data == (char *)MAP_FAILED) {
     res = MAIL_ERROR_FILE;
     
     goto err;
@@ -396,7 +400,7 @@ static int file_body_body_to_mmapstr(FILE * f,
   }
   
   data = mmap(NULL, buf.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (data == MAP_FAILED) {
+  if (data == (char *)MAP_FAILED) {
     res = MAIL_ERROR_FILE;
     
     goto err;
@@ -890,7 +894,7 @@ static int fetch_size(mailmessage * msg_info,
 
 
 static mailmessage_driver local_mime_message_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* msg_name */ "mime",
   
   /* msg_initialize */ initialize,
