@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: nntpdriver.c,v 1.48 2005/08/15 11:08:40 hoa Exp $
+ * $Id: nntpdriver.c,v 1.51 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "nntpdriver.h"
 
 #include <string.h>
@@ -54,23 +58,23 @@ static int nntpdriver_parameters(mailsession * session,
 static int nntpdriver_connect_stream(mailsession * session, mailstream * s);
 
 static int nntpdriver_login(mailsession * session,
-			    char * userid, char * password);
+			    const char * userid, const char * password);
 
 static int nntpdriver_logout(mailsession * session);
 
-static int nntpdriver_status_folder(mailsession * session, char * mb,
+static int nntpdriver_status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages,
     uint32_t * result_recent,
     uint32_t * result_unseen);
 
-static int nntpdriver_messages_number(mailsession * session, char * mb,
+static int nntpdriver_messages_number(mailsession * session, const char * mb,
 				      uint32_t * result);
 
 static int nntpdriver_append_message(mailsession * session,
-				     char * message, size_t size);
+				     const char * message, size_t size);
 
 static int nntpdriver_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags);
+    const char * message, size_t size, struct mail_flags * flags);
 
 static int
 nntpdriver_get_envelopes_list(mailsession * session,
@@ -80,15 +84,15 @@ nntpdriver_get_envelopes_list(mailsession * session,
 static int nntpdriver_get_messages_list(mailsession * session,
 					struct mailmessage_list ** result);
 
-static int nntpdriver_list_folders(mailsession * session, char * mb,
+static int nntpdriver_list_folders(mailsession * session, const char * mb,
 				   struct mail_list ** result);
 
-static int nntpdriver_lsub_folders(mailsession * session, char * mb,
+static int nntpdriver_lsub_folders(mailsession * session, const char * mb,
 				   struct mail_list ** result);
 
-static int nntpdriver_subscribe_folder(mailsession * session, char * mb);
+static int nntpdriver_subscribe_folder(mailsession * session, const char * mb);
 
-static int nntpdriver_unsubscribe_folder(mailsession * session, char * mb);
+static int nntpdriver_unsubscribe_folder(mailsession * session, const char * mb);
 
 static int nntpdriver_get_message(mailsession * session,
 				  uint32_t num, mailmessage ** result);
@@ -100,7 +104,7 @@ static int nntpdriver_get_message_by_uid(mailsession * session,
 static int nntpdriver_noop(mailsession * session);
 
 static mailsession_driver local_nntp_session_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "nntp",
 
   /* sess_initialize */ nntpdriver_initialize,
@@ -304,7 +308,7 @@ static int nntpdriver_parameters(mailsession * session,
 }
 
 
-static int add_to_list(mailsession * session, char * mb)
+static int add_to_list(mailsession * session, const char * mb)
 {
   char * new_mb;
   int r;
@@ -318,14 +322,14 @@ static int add_to_list(mailsession * session, char * mb)
 
   r = clist_append(data->nntp_subscribed_list, new_mb);
   if (r < 0) {
-    free(mb);
+    free(new_mb);
     return -1;
   }
 
   return 0;
 }
 
-static int remove_from_list(mailsession * session, char * mb)
+static int remove_from_list(mailsession * session, const char * mb)
 {
   clistiter * cur;
   struct nntp_session_state_data * data;
@@ -364,7 +368,7 @@ static int nntpdriver_connect_stream(mailsession * session, mailstream * s)
 }
 
 static int nntpdriver_login(mailsession * session,
-			    char * userid, char * password)
+			    const char * userid, const char * password)
 {
   struct nntp_session_state_data * data;
   char * new_userid;
@@ -410,7 +414,7 @@ static int nntpdriver_logout(mailsession * session)
 }
 
 
-static int nntpdriver_status_folder(mailsession * session, char * mb,
+static int nntpdriver_status_folder(mailsession * session, const char * mb,
 				    uint32_t * result_messages,
 				    uint32_t * result_recent,
 				    uint32_t * result_unseen)
@@ -433,7 +437,7 @@ static int nntpdriver_status_folder(mailsession * session, char * mb,
   return MAIL_NO_ERROR;
 }
 
-static int nntpdriver_messages_number(mailsession * session, char * mb,
+static int nntpdriver_messages_number(mailsession * session, const char * mb,
 				      uint32_t * result)
 {
   int r;
@@ -456,7 +460,7 @@ static int nntpdriver_messages_number(mailsession * session, char * mb,
   return MAIL_NO_ERROR;
 }
 
-static int nntpdriver_list_folders(mailsession * session, char * mb,
+static int nntpdriver_list_folders(mailsession * session, const char * mb,
 				    struct mail_list ** result)
 {
   int r;
@@ -566,7 +570,7 @@ static int nntpdriver_list_folders(mailsession * session, char * mb,
   return res;
 }
 
-static int nntpdriver_lsub_folders(mailsession * session, char * mb,
+static int nntpdriver_lsub_folders(mailsession * session, const char * mb,
 				   struct mail_list ** result)
 {
   clist * subscribed;
@@ -629,7 +633,7 @@ static int nntpdriver_lsub_folders(mailsession * session, char * mb,
   return res;
 }
 
-static int nntpdriver_subscribe_folder(mailsession * session, char * mb)
+static int nntpdriver_subscribe_folder(mailsession * session, const char * mb)
 {
   int r;
 
@@ -640,7 +644,7 @@ static int nntpdriver_subscribe_folder(mailsession * session, char * mb)
   return MAIL_NO_ERROR;
 }
 
-static int nntpdriver_unsubscribe_folder(mailsession * session, char * mb)
+static int nntpdriver_unsubscribe_folder(mailsession * session, const char * mb)
 {
   int r;
 
@@ -656,7 +660,7 @@ static int nntpdriver_unsubscribe_folder(mailsession * session, char * mb)
 /* messages operations */
 
 static int nntpdriver_append_message(mailsession * session,
-				     char * message, size_t size)
+				     const char * message, size_t size)
 {
   int r;
   struct nntp_session_state_data * data;
@@ -686,7 +690,7 @@ static int nntpdriver_append_message(mailsession * session,
 }
 
 static int nntpdriver_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags)
+    const char * message, size_t size, struct mail_flags * flags)
 {
   return nntpdriver_append_message(session, message, size);
 }
