@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: pop3driver_cached.c,v 1.44 2005/08/15 11:08:40 hoa Exp $
+ * $Id: pop3driver_cached.c,v 1.47 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "pop3driver_cached.h"
 
 #include "libetpan-config.h"
@@ -41,7 +45,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <string.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #include <stdlib.h>
@@ -72,7 +76,7 @@ static int pop3driver_cached_connect_stream(mailsession * session,
 static int pop3driver_cached_starttls(mailsession * session);
 
 static int pop3driver_cached_login(mailsession * session,
-    char * userid, char * password);
+    const char * userid, const char * password);
 
 static int pop3driver_cached_logout(mailsession * session);
 
@@ -83,19 +87,19 @@ static int pop3driver_cached_noop(mailsession * session);
 static int pop3driver_cached_expunge_folder(mailsession * session);
 
 static int pop3driver_cached_status_folder(mailsession * session,
-    char * mb, uint32_t * result_messages, uint32_t * result_recent,
+    const char * mb, uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen);
 
 static int pop3driver_cached_messages_number(mailsession * session,
-    char * mb,
+    const char * mb,
     uint32_t * result);
 
 static int pop3driver_cached_recent_number(mailsession * session,
-    char * mb,
+    const char * mb,
     uint32_t * result);
 
 static int pop3driver_cached_unseen_number(mailsession * session,
-    char * mb,
+    const char * mb,
     uint32_t * result);
 
 static int pop3driver_cached_remove_message(mailsession * session,
@@ -124,7 +128,7 @@ static int pop3driver_cached_login_sasl(mailsession * session,
     const char * password, const char * realm);
 
 static mailsession_driver local_pop3_cached_session_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "pop3-cached",
 
   /* sess_initialize */ pop3driver_cached_initialize,
@@ -418,7 +422,7 @@ static int pop3driver_cached_starttls(mailsession * session)
 
 
 static int pop3driver_cached_login(mailsession * session,
-    char * userid, char * password)
+    const char * userid, const char * password)
 {
   return mailsession_login(get_ancestor(session), userid, password);
 }
@@ -511,7 +515,7 @@ static int pop3driver_cached_expunge_folder(mailsession * session)
 }
 
 static int pop3driver_cached_status_folder(mailsession * session,
-    char * mb, uint32_t * result_messages, uint32_t * result_recent,
+    const char * mb, uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen)
 {
   int res;
@@ -598,14 +602,14 @@ static int pop3driver_cached_status_folder(mailsession * session,
 }
 
 static int pop3driver_cached_messages_number(mailsession * session,
-    char * mb,
+    const char * mb,
     uint32_t * result)
 {
   return mailsession_messages_number(get_ancestor(session), mb, result);
 }
 
 static int pop3driver_cached_recent_number(mailsession * session,
-    char * mb,
+    const char * mb,
     uint32_t * result)
 {
   uint32_t messages;
@@ -624,7 +628,7 @@ static int pop3driver_cached_recent_number(mailsession * session,
 }
 
 static int pop3driver_cached_unseen_number(mailsession * session,
-    char * mb,
+    const char * mb,
     uint32_t * result)
 {
   uint32_t messages;
