@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: pop3storage.c,v 1.14 2005/08/15 11:08:40 hoa Exp $
+ * $Id: pop3storage.c,v 1.17 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "pop3storage.h"
 
 #include <stdlib.h>
@@ -53,7 +57,7 @@ static int pop3_mailstorage_get_folder_session(struct mailstorage * storage,
 static void pop3_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver pop3_mailstorage_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
+#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sto_name               */ "pop3",
   /* sto_connect            */ pop3_mailstorage_connect,
   /* sto_get_folder_session */ pop3_mailstorage_get_folder_session,
@@ -68,11 +72,11 @@ static mailstorage_driver pop3_mailstorage_driver = {
 
 LIBETPAN_EXPORT
 int pop3_mailstorage_init(struct mailstorage * storage,
-    char * pop3_servername, uint16_t pop3_port,
-    char * pop3_command,
+    const char * pop3_servername, uint16_t pop3_port,
+    const char * pop3_command,
     int pop3_connection_type, int pop3_auth_type,
-    char * pop3_login, char * pop3_password,
-    int pop3_cached, char * pop3_cache_directory, char * pop3_flags_directory)
+    const char * pop3_login, const char * pop3_password,
+    int pop3_cached, const char * pop3_cache_directory, const char * pop3_flags_directory)
 {
   struct pop3_mailstorage * pop3_storage;
   int r;
@@ -101,8 +105,8 @@ int pop3_mailstorage_init(struct mailstorage * storage,
 
 LIBETPAN_EXPORT
 int pop3_mailstorage_init_sasl(struct mailstorage * storage,
-    char * pop3_servername, uint16_t pop3_port,
-    char * pop3_command,
+    const char * pop3_servername, uint16_t pop3_port,
+    const char * pop3_command,
     int pop3_connection_type,
     const char * auth_type,
     const char * server_fqdn,
@@ -110,8 +114,8 @@ int pop3_mailstorage_init_sasl(struct mailstorage * storage,
     const char * remote_ip_port,
     const char * login, const char * auth_name,
     const char * password, const char * realm,
-    int pop3_cached, char * pop3_cache_directory,
-    char * pop3_flags_directory)
+    int pop3_cached, const char * pop3_cache_directory,
+    const char * pop3_flags_directory)
 {
   struct pop3_mailstorage * pop3_storage;
 
