@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: maildriver_types.c,v 1.26 2005/06/01 12:22:00 smarinier Exp $
+ * $Id: maildriver_types.c,v 1.28 2006/06/16 09:23:38 smarinier Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "maildriver_types.h"
 #include <time.h>
 #include <stdlib.h>
@@ -346,3 +350,12 @@ void mail_flags_free(struct mail_flags * flags)
   free(flags);
 }
 
+LIBETPAN_EXPORT
+void *libetpan_malloc(size_t length) {
+	return malloc( length);
+}
+
+LIBETPAN_EXPORT
+void libetpan_free(void* data) {
+	free( data);
+}
