@@ -30,22 +30,21 @@
  */
 
 /*
- * $Id: generic_cache.c,v 1.30 2005/06/01 20:23:15 hoa Exp $
+ * $Id: generic_cache.c,v 1.32 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "generic_cache.h"
 
 #include "libetpan-config.h"
 
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
-#endif
-
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
-#if HAVE_SYS_MMAN_H
+#ifdef HAVE_SYS_MMAN_H
 #	include <sys/mman.h>
 #endif
 #ifdef _MSC_VER
@@ -102,7 +101,7 @@ int generic_cache_store(char * filename, char * content, size_t length)
     return MAIL_ERROR_FILE;
   
   str = mmap(NULL, length, PROT_READ | PROT_WRITE, MAP_SHARED, fd, 0);
-  if (str == MAP_FAILED)
+  if (str == (char *)MAP_FAILED)
     return MAIL_ERROR_FILE;
 
   memcpy(str, content, length);
@@ -135,7 +134,7 @@ int generic_cache_read(char * filename, char ** result, size_t * result_len)
   }
 
   str = mmap(NULL, buf.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (str == MAP_FAILED) {
+  if (str == (char *)MAP_FAILED) {
     res = MAIL_ERROR_FILE;
     goto close;
   }
