@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: imfcache.c,v 1.17 2005/06/01 16:04:43 hoa Exp $
+ * $Id: imfcache.c,v 1.18 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "imfcache.h"
 
 #include <stdlib.h>
@@ -126,7 +130,7 @@ static int mailimf_cache_mailbox_read(MMAPString * mmapstr, size_t * index,
 
 enum {
   CACHE_NULL_POINTER = 0,
-  CACHE_NOT_NULL     = 1,
+  CACHE_NOT_NULL     = 1
 };
 
 int mail_serialize_clear(MMAPString * mmapstr, size_t * index)
