@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailprivacy.c,v 1.6 2005/11/30 11:08:43 hoa Exp $
+ * $Id: mailprivacy.c,v 1.7 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailprivacy.h"
 
 #include <libetpan/libetpan.h>
