@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailprivacy_tools.c,v 1.8 2005/12/21 23:49:23 hoa Exp $
+ * $Id: mailprivacy_tools.c,v 1.10 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailprivacy_tools.h"
 
 #include <stdlib.h>
@@ -165,7 +169,7 @@ static char * dup_file(struct mailprivacy * privacy,
     goto close_src;
   
   mapping = mmap(NULL, stat_info.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (mapping == MAP_FAILED)
+  if (mapping == (char *)MAP_FAILED)
     goto close_src;
   
   written = fwrite(mapping, 1, stat_info.st_size, dest_f);
@@ -721,7 +725,7 @@ int mailprivacy_get_part_from_file(struct mailprivacy * privacy,
   }
 
   mapping = mmap(NULL, stat_info.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (mapping == MAP_FAILED) {
+  if (mapping == (char *)MAP_FAILED) {
     res = MAIL_ERROR_FILE;
     goto close;
   }
@@ -941,7 +945,7 @@ char * mailprivacy_dup_imf_file(struct mailprivacy * privacy,
     goto close_src;
   
   mapping = mmap(NULL, stat_info.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (mapping == MAP_FAILED)
+  if (mapping == (char *)MAP_FAILED)
     goto close_src;
   
   col = 0;
@@ -1004,7 +1008,7 @@ mailprivacy_mime_fields_dup(struct mailprivacy * privacy,
     goto unlink;
   
   mapping = mmap(NULL, stat_info.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (mapping == MAP_FAILED)
+  if (mapping == (char *)MAP_FAILED)
     goto unlink;
   
   cur_token = 0;
