@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap.c,v 1.34 2006/05/22 13:39:40 hoa Exp $
+ * $Id: mailimap.c,v 1.37 2006/10/20 00:13:30 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -216,6 +216,24 @@ static void resp_text_store(mailimap * session,
 	session->imap_selection_info->sel_first_unseen =
           resp_text_code->rc_data.rc_first_unseen;
       break;
+      
+    case MAILIMAP_RESP_TEXT_CODE_OTHER:
+      if (session->imap_response_info) {
+        if (session->imap_response_info->rsp_atom != NULL)
+          free(session->imap_response_info->rsp_atom);
+        if (session->imap_response_info->rsp_value != NULL)
+          free(session->imap_response_info->rsp_value);
+	session->imap_response_info->rsp_atom =
+          resp_text_code->rc_data.rc_atom.atom_name;
+        resp_text_code->rc_data.rc_atom.atom_name = NULL;
+	session->imap_response_info->rsp_value =
+          resp_text_code->rc_data.rc_atom.atom_value;
+        resp_text_code->rc_data.rc_atom.atom_value = NULL;
+      }
+      break;
+    case MAILIMAP_RESP_TEXT_CODE_EXTENSION:
+      mailimap_extension_data_store(session, &(resp_text_code->rc_data.rc_ext_data));
+      break;
     }
   }
 }
@@ -1593,7 +1611,13 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
   session->imap_sasl.sasl_secret = secret;
   
   /* init SASL */
-  mailsasl_ref();
+  if (session->imap_sasl.sasl_conn != NULL) {
+    sasl_dispose((sasl_conn_t **) &session->imap_sasl.sasl_conn);
+    session->imap_sasl.sasl_conn = NULL;
+  }
+  else {
+    mailsasl_ref();
+  }
   
   r = sasl_client_new("imap", server_fqdn,
       local_ip_port, remote_ip_port, sasl_callback, 0,
@@ -1607,30 +1631,30 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
       auth_type, NULL, &sasl_out, &sasl_out_len, &mechusing);
   if ((r != SASL_CONTINUE) && (r != SASL_OK)) {
     res = MAILIMAP_ERROR_LOGIN;
-    goto free_secret;
+    goto free_sasl_conn;
   }
   
   r = send_current_tag(session);
   if (r != MAILIMAP_NO_ERROR) {
     res = r;
-    goto free_secret;
+    goto free_sasl_conn;
   }
 
   r = mailimap_authenticate_send(session->imap_stream, auth_type);
   if (r != MAILIMAP_NO_ERROR) {
     res = r;
-    goto free_secret;
+    goto free_sasl_conn;
   }
 
   r = mailimap_crlf_send(session->imap_stream);
   if (r != MAILIMAP_NO_ERROR) {
     res = r;
-    goto free_secret;
+    goto free_sasl_conn;
   }
 
   if (mailstream_flush(session->imap_stream) == -1) {
     res = MAILIMAP_ERROR_STREAM;
-    goto free_secret;
+    goto free_sasl_conn;
   }
   
   while (1) {
@@ -1643,7 +1667,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
     
     if (read_line(session) == NULL) {
       res = MAILIMAP_ERROR_STREAM;
-      goto free_secret;
+      goto free_sasl_conn;
     }
     
     index = 0;
@@ -1678,7 +1702,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
       if (decoded == NULL) {
         mailimap_continue_req_free(cont_req);
         res = MAILIMAP_ERROR_MEMORY;
-        goto free_secret;
+        goto free_sasl_conn;
       }
       
       r = sasl_decode64(response, response_len,
@@ -1689,7 +1713,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
       if (r != SASL_OK) {
         free(decoded);
         res = MAILIMAP_ERROR_MEMORY;
-        goto free_secret;
+        goto free_sasl_conn;
       }
       
       r = sasl_client_step(session->imap_sasl.sasl_conn,
@@ -1699,7 +1723,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
       
       if ((r != SASL_CONTINUE) && (r != SASL_OK)) {
         res = MAILIMAP_ERROR_LOGIN;
-        goto free_secret;
+        goto free_sasl_conn;
       }
     }
     else {
@@ -1710,7 +1734,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
     encoded = malloc(max_encoded + 1);
     if (encoded == NULL) {
       res = MAILIMAP_ERROR_MEMORY;
-      goto free_secret;
+      goto free_sasl_conn;
     }
     
     r = sasl_encode64(sasl_out, sasl_out_len,
@@ -1718,7 +1742,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
     if (r != SASL_OK) {
       free(encoded);
       res = MAILIMAP_ERROR_MEMORY;
-      goto free_secret;
+      goto free_sasl_conn;
     }
     
     r = mailimap_token_send(session->imap_stream, encoded);
@@ -1727,27 +1751,28 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
     
     if (r != MAILIMAP_NO_ERROR) {
       res = r;
-      goto free_secret;
+      goto free_sasl_conn;
     }
     
     r = mailimap_crlf_send(session->imap_stream);
     if (r != MAILIMAP_NO_ERROR) {
       res = r;
-      goto free_secret;
+      goto free_sasl_conn;
     }
     
     if (mailstream_flush(session->imap_stream) == -1) {
       res = MAILIMAP_ERROR_STREAM;
-      goto free_secret;
+      goto free_sasl_conn;
     }
   }
   
   free(session->imap_sasl.sasl_secret);
+  session->imap_sasl.sasl_secret = NULL;
   
   r = parse_response(session, &response);
   if (r != MAILIMAP_NO_ERROR) {
     res = r;
-    goto err;
+    goto free_sasl_conn;
   }
   
   error_code = response->rsp_resp_done->rsp_data.rsp_tagged->rsp_cond_state->rsp_type;
@@ -1757,15 +1782,21 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
   switch (error_code) {
   case MAILIMAP_RESP_COND_STATE_OK:
     session->imap_state = MAILIMAP_STATE_AUTHENTICATED;
-    return MAILIMAP_NO_ERROR;
+    res = MAILIMAP_NO_ERROR;
+    goto free_sasl_conn;
     
   default:
     res = MAILIMAP_ERROR_LOGIN;
-    goto err;
+    goto free_sasl_conn;
   }
   
+ free_sasl_conn:
+  sasl_dispose((sasl_conn_t **) &session->imap_sasl.sasl_conn);
+  session->imap_sasl.sasl_conn = NULL;
+  mailsasl_unref();
  free_secret:
   free(session->imap_sasl.sasl_secret);
+  session->imap_sasl.sasl_secret = NULL;
  err:
   return res;
 #else
@@ -2374,11 +2405,13 @@ int parse_response(mailimap * session,
 #endif
 
   response_store(session, response);
-
-  if (mmap_string_assign(session->imap_response_buffer,
-          response->rsp_resp_done->rsp_data.rsp_tagged->rsp_cond_state->rsp_text->rsp_text)
-      == NULL)
-    return MAILIMAP_ERROR_MEMORY;
+  
+  if (response->rsp_resp_done->rsp_data.rsp_tagged->rsp_cond_state->rsp_text->rsp_text != NULL) {
+    if (mmap_string_assign(session->imap_response_buffer,
+            response->rsp_resp_done->rsp_data.rsp_tagged->rsp_cond_state->rsp_text->rsp_text)
+        == NULL)
+      return MAILIMAP_ERROR_MEMORY;
+  }
 
   session->imap_response = session->imap_response_buffer->str;
 
