@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap.h,v 1.17 2006/04/15 15:32:26 hoa Exp $
+ * $Id: mailimap.h,v 1.18 2006/10/20 00:13:30 hoa Exp $
  */
 
 #ifndef MAILIMAP_H
@@ -48,6 +48,10 @@ extern "C" {
 #include <libetpan/mailimap_socket.h>
 #include <libetpan/mailimap_ssl.h>
 
+#include <libetpan/acl.h>
+#include <libetpan/annotatemore.h>
+#include <libetpan/uidplus.h>
+
 /*
   mailimap_connect()
 
