@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_parser.h,v 1.9 2006/04/25 07:41:50 lemma Exp $
+ * $Id: mailimap_parser.h,v 1.10 2006/10/20 00:13:30 hoa Exp $
  */
 
 #ifndef MAILIMAP_PARSER_H
@@ -66,7 +66,7 @@ typedef int mailimap_struct_parser(mailstream * fd, MMAPString * buffer,
 				   size_t * index, void * result,
 				   size_t progr_rate,
 				   progress_function * progr_fun);
-typedef int mailimap_struct_destructor(void * result);
+typedef void mailimap_struct_destructor(void * result);
 
 int
 mailimap_mailbox_parse(mailstream * fd, MMAPString * buffer,
@@ -108,6 +108,25 @@ mailimap_astring_parse(mailstream * fd, MMAPString * buffer,
 		       size_t progr_rate,
 		       progress_function * progr_fun);
 
+int
+mailimap_nz_number_parse(mailstream * fd, MMAPString * buffer,
+			 size_t * index, uint32_t * result);
+
+int
+mailimap_struct_list_parse(mailstream * fd, MMAPString * buffer,
+    size_t * index, clist ** result,
+    char symbol,
+    mailimap_struct_parser * parser,
+    mailimap_struct_destructor * destructor,
+    size_t progr_rate,
+    progress_function * progr_fun);
+
+int mailimap_uniqueid_parse(mailstream * fd, MMAPString * buffer,
+    size_t * index, uint32_t * result);
+
+int mailimap_colon_parse(mailstream * fd, MMAPString * buffer,
+    size_t * index);
+
 #ifdef __cplusplus
 }
 #endif
