@@ -30,18 +30,24 @@
  */
 
 /*
- * $Id: mailimap_socket.c,v 1.12 2005/06/01 12:22:01 smarinier Exp $
+ * $Id: mailimap_socket.c,v 1.16 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailimap_socket.h"
 
 #include "mailimap.h"
 
 #include "connect.h"
-#if HAVE_NETINET_IN_H
+
+#include <stdlib.h>
+#ifdef HAVE_NETINET_IN_H
 #	include <netinet/in.h>
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 
@@ -49,6 +55,7 @@
 #define SERVICE_NAME_IMAP "imap2"
 #define SERVICE_TYPE_TCP "tcp"
 
+LIBETPAN_EXPORT
 int mailimap_socket_connect(mailimap * f, const char * server, uint16_t port)
 {
   int s;
@@ -58,7 +65,6 @@ int mailimap_socket_connect(mailimap * f, const char * server, uint16_t port)
     port = mail_get_service_port(SERVICE_NAME_IMAP, SERVICE_TYPE_TCP);
     if (port == 0)
       port = DEFAULT_IMAP_PORT;
-    port = ntohs(port);
   }
 
   /* Connection */
