@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_socket.h,v 1.13 2005/06/01 12:22:01 smarinier Exp $
+ * $Id: mailimap_socket.h,v 1.15 2006/05/22 13:39:41 hoa Exp $
  */
 
 #ifndef MAILIMAP_SOCKET_H
@@ -41,12 +41,13 @@
 extern "C" {
 #endif
 
-#if HAVE_INTTYPES_H
+#ifdef HAVE_INTTYPES_H
 #	include <inttypes.h>
 #endif
 
 #include <libetpan/mailimap_types.h>
 
+LIBETPAN_EXPORT
 int mailimap_socket_connect(mailimap * f, const char * server, uint16_t port);
 
 #ifdef __cplusplus
