@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailimap_types_helper.c,v 1.11 2004/11/21 21:53:36 hoa Exp $
+ * $Id: mailimap_types_helper.c,v 1.12 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailimap_types.h"
 #include "mail.h"
 
