@@ -1317,7 +1317,7 @@ struct mailimf_date_time * mailimf_get_current_date(void)
 
 
 /* mkgmtime.c - make time corresponding to a GMT timeval struct
- $Id: mailimf_types_helper.c,v 1.17 2006/05/22 13:39:42 hoa Exp $
+ $Id: mailimf_types_helper.c,v 1.18 2006/10/22 20:22:06 hoa Exp $
  
  * Copyright (c) 1998-2000 Carnegie Mellon University.  All rights reserved.
  *
@@ -1551,10 +1551,21 @@ void mailimf_single_fields_init(struct mailimf_single_fields * single_fields,
         cur = clist_next(cur);
       }
       else {
-        clist_concat(single_fields->fld_bcc->bcc_addr_list->ad_list,
-                     field->fld_data.fld_bcc->bcc_addr_list->ad_list);
-        mailimf_field_free(field);
-        cur = clist_delete(fields->fld_list, cur);
+        if (field->fld_data.fld_bcc->bcc_addr_list != NULL) {
+          if (single_fields->fld_bcc->bcc_addr_list == NULL) {
+            single_fields->fld_bcc->bcc_addr_list = field->fld_data.fld_bcc->bcc_addr_list;
+            field->fld_data.fld_bcc->bcc_addr_list = NULL;
+          }
+          else {
+            clist_concat(single_fields->fld_bcc->bcc_addr_list->ad_list,
+                field->fld_data.fld_bcc->bcc_addr_list->ad_list);
+          }
+          mailimf_field_free(field);
+          cur = clist_delete(fields->fld_list, cur);
+        }
+        else {
+          cur = clist_next(cur);
+        }
       }
       break;
     case MAILIMF_FIELD_MESSAGE_ID:
