@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildir.c,v 1.16 2006/06/26 11:50:27 hoa Exp $
+ * $Id: maildir.c,v 1.17 2006/10/12 08:00:21 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -99,6 +99,7 @@ struct maildir * maildir_new(const char * path)
 }
 
 static void maildir_flush(struct maildir * md, int msg_new);
+static void msg_free(struct maildir_msg * msg);
 
 void maildir_free(struct maildir * md)
 {
@@ -423,10 +424,7 @@ int maildir_update(struct maildir * md)
   }
   
   if (changed) {
-    
-    carray_set_size(md->mdir_msg_list, 0);
-    chash_clear(md->mdir_msg_hash);
-    
+    maildir_flush(md, 0);
     maildir_flush(md, 1);
     
     /* messages in new */
@@ -436,8 +434,6 @@ int maildir_update(struct maildir * md)
       goto free;
     }
     
-    maildir_flush(md, 0);
-
     /* messages in cur */
     r = add_directory(md, path_cur, 0);
     if (r != MAILDIR_NO_ERROR) {
