@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailmbox.c,v 1.42 2005/08/13 14:52:23 hoa Exp $
+ * $Id: mailmbox.c,v 1.44 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailmbox.h"
 
 #ifdef _MSC_VER
@@ -155,7 +159,7 @@ int mailmbox_map(struct mailmbox_folder * folder)
   else
     str = (char *) mmap(0, buf.st_size, PROT_READ | PROT_WRITE,
 			MAP_SHARED, folder->mb_fd, 0);
-  if (str == MAP_FAILED) {
+  if (str == (char *)MAP_FAILED) {
     res = MAILMBOX_ERROR_FILE;
     goto err;
   }
@@ -1205,7 +1209,7 @@ static int mailmbox_expunge_to_file_no_lock(char * dest_filename, int dest_fd,
   }
 
   dest = (char *) mmap(0, size, PROT_READ | PROT_WRITE, MAP_SHARED, dest_fd, 0);
-  if (dest == MAP_FAILED) {
+  if (dest == (char *)MAP_FAILED) {
     res = MAILMBOX_ERROR_FILE;
     goto err;
   }
@@ -1278,7 +1282,7 @@ static int copy_to_old_file(char * source_filename,
   }
   
   source = (char *) mmap(0, size, PROT_READ, MAP_PRIVATE, source_fd, 0);
-  if (source == MAP_FAILED) {
+  if (source == (char *)MAP_FAILED) {
     res = MAILMBOX_ERROR_FILE;
     goto close_source;
   }
@@ -1297,7 +1301,7 @@ static int copy_to_old_file(char * source_filename,
   
   dest = (char *) mmap(0, size, PROT_READ | PROT_WRITE,
       MAP_SHARED, dest_fd, 0);
-  if (dest == MAP_FAILED) {
+  if (dest == (char *)MAP_FAILED) {
     res = MAILMBOX_ERROR_FILE;
     goto close_dest;
   }
