@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmh.h,v 1.25 2005/06/01 20:23:16 hoa Exp $
+ * $Id: mailmh.h,v 1.26 2006/05/22 13:39:42 hoa Exp $
  */
 
 #ifndef MAILMH_H
@@ -54,7 +54,7 @@ enum {
   MAILMH_ERROR_FILE,
   MAILMH_ERROR_COULD_NOT_ALLOC_MSG,
   MAILMH_ERROR_RENAME,
-  MAILMH_ERROR_MSG_NOT_FOUND,
+  MAILMH_ERROR_MSG_NOT_FOUND
 };
 
 struct mailmh {
