@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailmime_content.c,v 1.40 2005/06/01 12:22:19 smarinier Exp $
+ * $Id: mailmime_content.c,v 1.41 2006/05/22 13:39:42 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailimf.h"
 
 #include <string.h>
@@ -1914,7 +1918,7 @@ enum {
   STATE_NORMAL,
   STATE_CODED,
   STATE_OUT,
-  STATE_CR,
+  STATE_CR
 };
 
 
