@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_decode.c,v 1.28 2006/06/26 11:50:27 hoa Exp $
+ * $Id: mailmime_decode.c,v 1.30 2006/10/07 17:04:18 hoa Exp $
  */
 
 /*
@@ -143,8 +143,14 @@ int mailmime_encoded_phrase_parse(const char * default_fromcode,
       }
       type = TYPE_ENCODED_WORD;
       wordutf8 = NULL;
-      r = charconv(tocode, word->wd_charset, word->wd_text,
-		   strlen(word->wd_text), &wordutf8);
+      if (strcasecmp(word->wd_charset, "unknown") == 0) {
+        r = charconv(tocode, "iso-8859-1", word->wd_text,
+            strlen(word->wd_text), &wordutf8);
+      }
+      else {
+        r = charconv(tocode, word->wd_charset, word->wd_text,
+            strlen(word->wd_text), &wordutf8);
+      }
       switch (r) {
       case MAIL_CHARCONV_ERROR_MEMORY:
 	mailmime_encoded_word_free(word);
@@ -223,7 +229,17 @@ int mailmime_encoded_phrase_parse(const char * default_fromcode,
 	first = FALSE;
       }
       else if (r == MAILIMF_ERROR_PARSE) {
-	break;
+        r = mailimf_fws_parse(message, length, &cur_token);
+        if (r != MAILIMF_NO_ERROR) {
+          break;
+        }
+        
+        if (mmap_string_append_c(gphrase, ' ') == NULL) {
+          res = MAILIMF_ERROR_MEMORY;
+          goto free;
+        }
+	first = FALSE;
+        break;
       }
       else {
 	res = r;
