@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailmime_disposition.c,v 1.12 2005/06/01 16:04:46 hoa Exp $
+ * $Id: mailmime_disposition.c,v 1.13 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailmime_disposition.h"
 #include "mailmime.h"
 
