@@ -30,23 +30,22 @@
  */
 
 /*
- * $Id: mailmime_types_helper.c,v 1.24 2005/06/01 20:23:16 hoa Exp $
+ * $Id: mailmime_types_helper.c,v 1.26 2006/06/26 11:50:27 hoa Exp $
  */
 
-#include "mailmime_types_helper.h"
-
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
 #endif
 
+#include "mailmime_types_helper.h"
+
 #include "clist.h"
 #include "mailmime.h"
 
 #include <string.h>
 #include <time.h>
 #include <sys/types.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 #include <stdlib.h>
