@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailmime_write.c,v 1.24 2004/11/21 21:53:39 hoa Exp $
+ * $Id: mailmime_write.c,v 1.25 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailmime_write.h"
 
 #include <stdlib.h>
@@ -1014,7 +1018,7 @@ int mailmime_data_write(FILE * f, int * col,
 
     if (buf.st_size != 0) {
       text = mmap(NULL, buf.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-      if (text == MAP_FAILED) {
+      if (text == (char *)MAP_FAILED) {
 	res = MAILIMF_ERROR_FILE;
 	goto close;
       }
