@@ -30,26 +30,25 @@
  */
 
 /*
- * $Id: mailmime_write_generic.c,v 1.4 2005/06/01 20:23:17 hoa Exp $
+ * $Id: mailmime_write_generic.c,v 1.6 2006/06/26 11:50:27 hoa Exp $
  */
 
-#include "mailmime_write_generic.h"
-
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
 #endif
 
+#include "mailmime_write_generic.h"
+
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#if HAVE_SYS_MMAN_H
+#ifdef HAVE_SYS_MMAN_H
 #	include <sys/mman.h>
 #endif
 #ifdef _MSC_VER
@@ -1026,7 +1025,7 @@ int mailmime_data_write_driver(int (* do_write)(void *, const char *, size_t), v
 
     if (buf.st_size != 0) {
       text = mmap(NULL, buf.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-      if (text == MAP_FAILED) {
+      if (text == (char *)MAP_FAILED) {
 	res = MAILIMF_ERROR_FILE;
 	goto close;
       }
@@ -1176,7 +1175,7 @@ enum {
   STATE_INIT,
   STATE_CR,
   STATE_SPACE,
-  STATE_SPACE_CR,
+  STATE_SPACE_CR
 };
 
 #if 0
