@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: newsnntp.h,v 1.18 2005/06/01 12:22:20 smarinier Exp $
+ * $Id: newsnntp.h,v 1.19 2006/05/22 13:39:42 hoa Exp $
  */
 
 #ifndef NEWSNNTP_H
@@ -41,7 +41,7 @@
 extern "C" {
 #endif
 
-#if HAVE_INTTYPES_H
+#ifdef HAVE_INTTYPES_H
 #	include <inttypes.h>
 #endif
 #include <sys/types.h>
