@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: newsnntp_types.h,v 1.13 2005/06/01 20:23:17 hoa Exp $
+ * $Id: newsnntp_types.h,v 1.14 2006/05/22 13:39:42 hoa Exp $
  */
 
 #ifndef NEWSNNTP_TYPES_H
@@ -69,7 +69,7 @@ enum {
   NEWSNNTP_ERROR_CONNECTION_REFUSED,
   NEWSNNTP_ERROR_MEMORY,
   NEWSNNTP_ERROR_AUTHENTICATION_REJECTED,
-  NEWSNNTP_ERROR_BAD_STATE,
+  NEWSNNTP_ERROR_BAD_STATE
 };
 
 struct newsnntp
