@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3.c,v 1.26 2006/05/22 13:39:42 hoa Exp $
+ * $Id: mailpop3.c,v 1.28 2006/08/29 23:14:02 hoa Exp $
  */
 
 /*
@@ -1043,8 +1043,9 @@ static int parse_auth(mailpop3 * f, char * response)
     return RESPONSE_ERR;
   }
 
-  if (strncmp(response, RESP_AUTH_CONT_STR, strlen(RESP_AUTH_CONT_STR)) == 0) {
-
+  if ((strncmp(response, RESP_AUTH_CONT_STR, strlen(RESP_AUTH_CONT_STR)) == 0) &&
+      (strncmp(response, RESP_OK_STR, strlen(RESP_OK_STR)) != 0)) {
+    
     if (response[strlen(RESP_AUTH_CONT_STR)] == ' ')
       msg = response + strlen(RESP_AUTH_CONT_STR) + 1;
     else
@@ -1401,7 +1402,13 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
   f->pop3_sasl.sasl_secret = secret;
   
   /* init SASL */
-  mailsasl_ref();
+  if (f->pop3_sasl.sasl_conn != NULL) {
+    sasl_dispose((sasl_conn_t **) &f->pop3_sasl.sasl_conn);
+    f->pop3_sasl.sasl_conn = NULL;
+  }
+  else {
+    mailsasl_ref();
+  }
   
   r = sasl_client_new("pop", server_fqdn,
       local_ip_port, remote_ip_port, sasl_callback, 0,
@@ -1415,7 +1422,7 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
       auth_type, NULL, &sasl_out, &sasl_out_len, &mechusing);
   if ((r != SASL_CONTINUE) && (r != SASL_OK)) {
     res = MAILPOP3_ERROR_BAD_USER;
-    goto free_secret;
+    goto free_sasl_conn;
   }
   
   snprintf(command, POP3_STRING_SIZE, "AUTH %s\r\n", auth_type);
@@ -1423,7 +1430,7 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
   r = send_command(f, command);
   if (r == -1) {
     res = MAILPOP3_ERROR_STREAM;
-    goto free_secret;
+    goto free_sasl_conn;
   }
   
   while (1) {
@@ -1434,12 +1441,12 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
     r = parse_auth(f, response);
     switch (r) {
     case RESPONSE_OK:
-      free(f->pop3_sasl.sasl_secret);
-      return MAILPOP3_NO_ERROR;
+      res = MAILPOP3_NO_ERROR;
+      goto free_sasl_conn;
       
     case RESPONSE_ERR:
       res = MAILPOP3_ERROR_BAD_USER;
-      goto free_secret;
+      goto free_sasl_conn;
     
     case RESPONSE_AUTH_CONT:
       {
@@ -1459,7 +1466,7 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
           decoded = malloc(max_decoded + 1);
           if (decoded == NULL) {
             res = MAILPOP3_ERROR_MEMORY;
-            goto free_secret;
+            goto free_sasl_conn;
           }
           
           r = sasl_decode64(f->pop3_response, response_len,
@@ -1468,7 +1475,7 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
           if (r != SASL_OK) {
             free(decoded);
             res = MAILPOP3_ERROR_MEMORY;
-            goto free_secret;
+            goto free_sasl_conn;
           }
           
           r = sasl_client_step(f->pop3_sasl.sasl_conn,
@@ -1478,7 +1485,7 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
           
           if ((r != SASL_CONTINUE) && (r != SASL_OK)) {
             res = MAILPOP3_ERROR_BAD_USER;
-            goto free_secret;
+            goto free_sasl_conn;
           }
         }
         
@@ -1486,7 +1493,7 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
         encoded = malloc(max_encoded + 1);
         if (encoded == NULL) {
           res = MAILPOP3_ERROR_MEMORY;
-          goto free_secret;
+          goto free_sasl_conn;
         }
         
         r = sasl_encode64(sasl_out, sasl_out_len,
@@ -1494,7 +1501,7 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
         if (r != SASL_OK) {
           free(encoded);
           res = MAILPOP3_ERROR_MEMORY;
-          goto free_secret;
+          goto free_sasl_conn;
         }
         
         snprintf(command, POP3_STRING_SIZE, "%s\r\n", encoded);
@@ -1504,17 +1511,22 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
         
         if (r == -1) {
           res = MAILPOP3_ERROR_STREAM;
-          goto free_secret;
+          goto free_sasl_conn;
         }
       }
       break;
     }
   }
+
+  res = MAILPOP3_NO_ERROR;
   
-  return MAILPOP3_NO_ERROR;
-  
+ free_sasl_conn:
+  sasl_dispose((sasl_conn_t **) &f->pop3_sasl.sasl_conn);
+  f->pop3_sasl.sasl_conn = NULL;
+  mailsasl_unref();
  free_secret:
   free(f->pop3_sasl.sasl_secret);
+  f->pop3_sasl.sasl_secret = NULL;
  err:
   return res;
 #else
