@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3.h,v 1.15 2005/01/28 01:43:13 hoa Exp $
+ * $Id: mailpop3.h,v 1.16 2005/07/16 17:55:57 hoa Exp $
  */
 
 #ifndef MAILPOP3_H
@@ -94,6 +94,13 @@ void mailpop3_capa_resp_free(clist * capa_list);
 
 int mailpop3_stls(mailpop3 * f);
 
+int mailpop3_auth(mailpop3 * f, const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm);
+
 #ifdef __cplusplus
 }
 #endif
