@@ -30,18 +30,22 @@
  */
 
 /*
- * $Id: mailpop3_ssl.c,v 1.12 2005/11/02 17:31:18 hoa Exp $
+ * $Id: mailpop3_ssl.c,v 1.13 2006/05/22 13:39:42 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailpop3_ssl.h"
 
 #include "mailpop3.h"
 
 #include "connect.h"
-#if HAVE_NETINET_IN_H
+#ifdef HAVE_NETINET_IN_H
 #	include <netinet/in.h>
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 
