@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3_ssl.h,v 1.14 2005/06/01 12:22:21 smarinier Exp $
+ * $Id: mailpop3_ssl.h,v 1.15 2006/05/22 13:39:42 hoa Exp $
  */
 
 #ifndef MAILPOP3_SSL_H
@@ -41,7 +41,7 @@
 extern "C" {
 #endif
 
-#if HAVE_INTTYPES_H
+#ifdef HAVE_INTTYPES_H
 #	include <inttypes.h>
 #endif
 
