@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3_types.h,v 1.17 2005/07/16 17:55:57 hoa Exp $
+ * $Id: mailpop3_types.h,v 1.18 2006/05/22 13:39:42 hoa Exp $
  */
 
 #ifndef MAILPOP3_TYPES_H
@@ -61,7 +61,7 @@ enum {
   MAILPOP3_ERROR_CONNECTION_REFUSED,
   MAILPOP3_ERROR_APOP_NOT_SUPPORTED,
   MAILPOP3_ERROR_CAPA_NOT_SUPPORTED,
-  MAILPOP3_ERROR_STLS_NOT_SUPPORTED,
+  MAILPOP3_ERROR_STLS_NOT_SUPPORTED
 };
 
 struct mailpop3
