@@ -30,18 +30,24 @@
  */
 
 /*
- * $Id: mailsmtp_socket.c,v 1.13 2006/02/15 17:57:14 colinleroy Exp $
+ * $Id: mailsmtp_socket.c,v 1.16 2006/06/26 11:50:28 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailsmtp_socket.h"
 
 #include "mailsmtp.h"
 
 #include "connect.h"
-#if HAVE_NETINET_IN_H
+
+#include <stdlib.h>
+#ifdef HAVE_NETINET_IN_H
 #	include <netinet/in.h>
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 
@@ -59,7 +65,6 @@ int mailsmtp_socket_connect(mailsmtp * session,
     port = mail_get_service_port(SERVICE_NAME_SMTP, SERVICE_TYPE_TCP);
     if (port == 0)
       port = DEFAULT_SMTP_PORT;
-    port = ntohs(port);
   }
 
   /* Connection */
