@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailsmtp_ssl.h,v 1.13 2005/06/01 12:22:21 smarinier Exp $
+ * $Id: mailsmtp_ssl.h,v 1.14 2006/05/22 13:39:43 hoa Exp $
  */
 
 #ifndef MAILSMTP_SSL_H
@@ -41,7 +41,7 @@
 extern "C" {
 #endif
 
-#if HAVE_INTTYPES_H
+#ifdef HAVE_INTTYPES_H
 #	include <inttypes.h>
 #endif
 
