@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailsmtp_types.h,v 1.14 2006/05/22 13:39:43 hoa Exp $
+ * $Id: mailsmtp_types.h,v 1.16 2006/10/13 14:24:03 alfie Exp $
  */
 
 #ifndef MAILSMTP_TYPES_H
@@ -70,7 +70,8 @@ enum {
   MAILSMTP_ERROR_AUTH_ENCRYPTION_REQUIRED,
   MAILSMTP_ERROR_STARTTLS_TEMPORARY_FAILURE,
   MAILSMTP_ERROR_STARTTLS_NOT_SUPPORTED,
-  MAILSMTP_ERROR_CONNECTION_REFUSED
+  MAILSMTP_ERROR_CONNECTION_REFUSED,
+  MAILSMTP_ERROR_AUTH_AUTHENTICATION_FAILED
 };
 
 enum {
