@@ -7,11 +7,14 @@
 #define DEST_CHARSET "iso-8859-1"
 
 enum {
+/* SEB */
+#ifndef NO_ERROR 
   NO_ERROR,
-  ERROR_FILE,
-  ERROR_MEMORY,
-  ERROR_INVAL,
-  ERROR_FETCH,
+#endif
+  ERROR_FILE = 1,
+  ERROR_MEMORY = 2,
+  ERROR_INVAL = 3,
+  ERROR_FETCH = 4,
 };
 
 int etpan_mime_is_text(struct mailmime * build_info);
